# caer
A Computer Vision library in Python with powerful image processing operations, including support for Deep Learning models built using the Keras framework

## Installation
The `caer` package can be installed via a simple pip install command 

<pre>$ pip install caer</pre>

## Notes
This repository is actively being maintained. If there are any issues, kindly open a thread in the `Issues` pane on this page. 